@@ -6,6 +6,7 @@
 
 from .image import Image
 from .listinput import ListInput
+from .booldicttoolbutton import BoolDictToolButton
 from .optionalwidget import OptionalWidget
 from .mappedcheckbox import MappedCheckBox
 from .stringornumberwidget import StringOrNumberWidget
@@ -25,9 +26,11 @@ from .buttondelegate import ButtonDelegate
 from .radiodelegate import RadioDelegate
 from .selectionwidget import SelectionWidget
 from .codeeditor import CodeEditor
+from .regexeditor.editor import RegexEditorWidget
 
 __all__ = ["Image",
            "ListInput",
+           "BoolDictToolButton",
            "OptionalWidget",
            "MappedCheckBox",
            "StringOrNumberWidget",
@@ -46,4 +49,5 @@ __all__ = ["Image",
            "SelectionWidget",
            "ImageViewer",
            "MarkdownWindow",
-           "CodeEditor"]
+           "CodeEditor",
+           "RegexEditorWidget"]
