@@ -11,9 +11,10 @@ from prettyqt import custom_validators, custom_widgets, gui, widgets
 
 
 class DataItem(object):
-    def __init__(self, label, *args, **kwargs):
-        self.value = None
+    def __init__(self, label, value=None, optional=False):
+        self.set_value(value)
         self.label = label
+        self.optional = optional
         self.colspan = 1
         self.label_col = 0
         self.active_on = list()
@@ -30,6 +31,9 @@ class DataItem(object):
         self.colspan = colspan
         return self
 
+    def set_value(self, value):
+        self.value = value
+
     def store(self, prop):
         # self.set_prop("display", store=prop)
         return self
@@ -47,6 +51,19 @@ class DataItem(object):
     def is_valid(self):
         return True
 
+    def create_widget(self):
+        widget = self._create_widget()
+        if self.optional:
+            return custom_widgets.OptionalWidget(widget, self.optional)
+        return widget
+
+    def _create_widget(self):
+        return None
+
+
+class Fixed(DataItem):
+    pass
+
 
 class Float(DataItem):
     """
@@ -63,15 +80,13 @@ class Float(DataItem):
     """
 
     def __init__(self, label, value=None, min_val=None, max_val=None,
-                 unit="", step=0.1, slider=False, check=True):
-        super().__init__(label, value=value, min_val=min_val,
-                         max_val=max_val, unit=unit, check=check)
-        self.value = value
+                 unit="", step=0.1, slider=False, optional=False):
+        super().__init__(label, value=value, optional=optional)
         self.range = (min_val, max_val)
         self.step = step
         self.unit = unit
 
-    def create_widget(self):
+    def _create_widget(self):
         widget = widgets.DoubleSpinBox()
         widget.set_range(*self.range)
         widget.setSingleStep(self.step)
@@ -95,16 +110,14 @@ class Int(DataItem):
     """
 
     def __init__(self, label, value=None, min_val=0, max_val=None,
-                 unit="", step=1, slider=False, check=True):
-        super().__init__(label, value=value, min_val=min_val, max_val=max_val,
-                         unit=unit, check=check)
-        self.value = value
+                 unit="", step=1, slider=False, optional=False):
+        super().__init__(label, value=value, optional=optional)
         self.range = (min_val, max_val)
         self.step = step
         self.unit = unit
         self.slider = slider
 
-    def create_widget(self):
+    def _create_widget(self):
         if self.slider:
             widget = custom_widgets.InputAndSlider()
         else:
@@ -125,13 +138,12 @@ class String(DataItem):
         * notempty [bool]: if True, empty string is not a valid value (opt.)
     """
 
-    def __init__(self, label, value=None, notempty=False, regex=None):
-        super().__init__(label, value=value)
-        self.value = value
+    def __init__(self, label, value=None, notempty=False, regex=None, optional=False):
+        super().__init__(label, value=value, optional=optional)
         self.notempty = notempty
         self.regex = regex
 
-    def create_widget(self):
+    def _create_widget(self):
         widget = widgets.LineEdit()
         if self.notempty:
             val = custom_validators.NotEmptyValidator()
@@ -145,6 +157,44 @@ class String(DataItem):
         return widget
 
 
+class IntList(DataItem):
+    """
+    Construct an IntList data item
+        * label [string]: name
+        * value [string]: default value (optional)
+        * notempty [bool]: if True, empty string is not a valid value (opt.)
+    """
+
+    def __init__(self, label, value=None, allow_single=False, optional=False):
+        super().__init__(label, value=value, optional=optional)
+        self.allow_single = allow_single
+
+    def _create_widget(self):
+        widget = custom_widgets.ListInput(allow_single=self.allow_single)
+        if self.value is not None:
+            widget.set_value(self.value)
+        return widget
+
+
+class FloatList(DataItem):
+    """
+    Construct an FloatList data item
+        * label [string]: name
+        * value [string]: default value (optional)
+        * notempty [bool]: if True, empty string is not a valid value (opt.)
+    """
+
+    def __init__(self, label, value=None, allow_single=False, optional=False):
+        super().__init__(label, value=value, optional=optional)
+        self.allow_single = allow_single
+
+    def _create_widget(self):
+        widget = custom_widgets.ListInput(allow_single=self.allow_single, typ=float)
+        if self.value is not None:
+            widget.set_value(self.value)
+        return widget
+
+
 class Bool(DataItem):
     """
     Construct a boolean data item
@@ -154,17 +204,15 @@ class Bool(DataItem):
         * check [bool]: if False, value is not checked (optional, value=True)
     """
 
-    def __init__(self, label, value=False, check=True, use_push=False):
-        super().__init__(label, value=value, check=check)
-        self.use_push = use_push
-        self.value = value
+    def __init__(self, label, value=False, optional=False,
+                 true_value=True, false_value=False):
+        super().__init__(label, value=value, optional=optional)
+        self.true_value = true_value
+        self.false_value = false_value
 
-    def create_widget(self):
-        if self.use_push:
-            widget = widgets.PushButton()
-            widget.setCheckable(True)
-        else:
-            widget = widgets.CheckBox()
+    def _create_widget(self):
+        widget = custom_widgets.MappedCheckBox(true_value=self.true_value,
+                                               false_value=self.false_value)
         if self.value is not None:
             widget.set_value(self.value)
         return widget
@@ -180,11 +228,10 @@ class Color(DataItem):
     Color values are encoded as hexadecimal strings or Qt color names
     """
 
-    def __init__(self, label, value=None, check=True):
-        super().__init__(label, value=value, check=check)
-        self.value = value
+    def __init__(self, label, value=None, optional=False):
+        super().__init__(label, value=value, optional=optional)
 
-    def create_widget(self):
+    def _create_widget(self):
         widget = custom_widgets.ColorChooserButton()
         if self.value is not None:
             widget.set_value(self.value)
@@ -205,13 +252,12 @@ class Enum(DataItem):
           (default is False)
     """
 
-    def __init__(self, label, choices, value=None, check=True, radio=False):
-        super().__init__(label, value=value, check=check)
-        self.value = value
+    def __init__(self, label, choices, value=None, optional=False, radio=False):
+        super().__init__(label, value=value, optional=optional)
         self.radio = radio
         self.choices = choices
 
-    def create_widget(self):
+    def _create_widget(self):
         if self.radio:
             widget = custom_widgets.SelectionWidget(layout="vertical")
         else:
@@ -231,12 +277,11 @@ class Enum(DataItem):
 
 class MultipleChoice(DataItem):
 
-    def __init__(self, label, choices, value=None, check=True):
-        super().__init__(label, value=value, check=check)
-        self.value = value
+    def __init__(self, label, choices, value=None, optional=False):
+        super().__init__(label, value=value, optional=optional)
         self.choices = choices
 
-    def create_widget(self):
+    def _create_widget(self):
         widget = widgets.ListWidget()
         widget.set_selection_mode("multi")
         for item in self.choices:
@@ -255,14 +300,13 @@ class MultipleChoice(DataItem):
 class File(DataItem):
 
     def __init__(self, label, formats="*", value=None, save=True,
-                 root=None, check=True):
-        super().__init__(label, value=value, check=check)
-        self.value = value
+                 root=None, optional=False):
+        super().__init__(label, value=value, optional=optional)
         self.formats = formats.lstrip(".")
         self.root = root
         self.save = save
 
-    def create_widget(self):
+    def _create_widget(self):
         file_mode = "any_file" if self.save else "existing_file"
         mode = "save" if self.save else "open"
         widget = custom_widgets.FileChooserButton(file_mode=file_mode,
@@ -275,13 +319,12 @@ class File(DataItem):
 
 class Folder(DataItem):
 
-    def __init__(self, label, value=None, root=None, mode="open", check=True):
-        super().__init__(label, value=value, check=check)
-        self.value = value
+    def __init__(self, label, value=None, root=None, mode="open", optional=False):
+        super().__init__(label, value=value, optional=optional)
         self.mode = mode
         self.root = root
 
-    def create_widget(self):
+    def _create_widget(self):
         widget = custom_widgets.FileChooserButton(file_mode="directory",
                                                   mode=self.mode,
                                                   root=self.root)
@@ -290,6 +333,15 @@ class Folder(DataItem):
         return widget
 
 
+class StringOrNumber(DataItem):
+
+    def _create_widget(self):
+        widget = custom_widgets.StringOrNumberWidget(self.label)
+        if self.value is not None:
+            widget.set_value(self.value)
+        return widget
+
+
 class Button(DataItem):
     """
     Construct a simple button that calls a method when hit
@@ -304,14 +356,13 @@ class Button(DataItem):
         * check [bool]: if False, value is not checked (optional, value=True)
     """
 
-    def __init__(self, label, callback, icon=None, value=None, check=True):
-        super().__init__("", value=value, check=check)
+    def __init__(self, label, callback, icon=None, value=None):
+        super().__init__("", value=value)
         self.button_label = label
         self.icon = icon
-        self.value = value
         self.callback = callback
 
-    def create_widget(self):
+    def _create_widget(self):
         widget = widgets.PushButton(self.button_label)
         widget.set_icon(self.icon)
         if self.value is not None:
@@ -361,6 +412,7 @@ class DataSet(object, metaclass=DataSetMeta):
         self.ok_btn = button_box.add_default_button("ok", callback=dialog.accept)
         button_box.add_default_button("cancel", callback=dialog.reject)
         widget_dict = {k: v.create_widget() for k, v in self._items.items()}
+        widget_dict = {k: v for k, v in widget_dict.items() if v is not None}
 
         def on_update():
             is_valid = all(i.is_valid() if hasattr(i, "is_valid") else True
@@ -403,7 +455,7 @@ class DataSet(object, metaclass=DataSetMeta):
         #               for a, b in dct.items()}
         for k, item in self._items.items():
             if k in new_values:
-                item.value = new_values[k]
+                item.set_value(new_values[k])
         return True
 
     def to_dict(self) -> dict:
@@ -423,9 +475,10 @@ if __name__ == "__main__":
         string2 = String(label="String Notempty", notempty=True)
         enum = Enum(label="Enum", choices=["A", "B"]).set_not_active("boolitem")
         floatitem = Float(label="Float").set_active("boolitem")
-        fileitem = File(label="File")
+        fileitem = File(label="File", optional="Activate")
         folderitem = Folder(label="Folder")
         buttonitem = Button(label="Folder", icon="mdi.folder", callback=print)
+        stringornumber = StringOrNumber(label="StringOrNumber", value=2.4)
 
     dlg = Test(icon="mdi.timer", comment="hallo")
     # dlg.widget.value_changed.connect(print)
