@@ -8,5 +8,6 @@ contains some custom syntax highlighers
 from .jsonhighlighter import JsonHighlighter
 from .pythonhighlighter import PythonHighlighter
 from .yamlhighlighter import YamlHighlighter
+from .xmlhighlighter import XmlHighlighter
 
-__all__ = ["JsonHighlighter", "YamlHighlighter", "PythonHighlighter"]
+__all__ = ["JsonHighlighter", "YamlHighlighter", "PythonHighlighter", "XmlHighlighter"]
