@@ -3,7 +3,10 @@
 @author: Philipp Temminghoff
 """
 
-from qtpy import QtCore, QtWebEngineWidgets
+from typing import Union
+import pathlib
+
+from qtpy import QtWebEngineWidgets
 
 from prettyqt import core, widgets
 
@@ -14,18 +17,22 @@ class WebEngineView(QtWebEngineWidgets.QWebEngineView):
 
     @classmethod
     def from_local_file(cls, path):
-        url = QtCore.QUrl.fromLocalFile(str(path))
+        url = core.Url.fromLocalFile(str(path))
         reader = cls()
         reader.setUrl(url)
         return reader
 
-    def set_url(self, url):
-        if isinstance(url, str):
+    def set_url(self, url: Union[str, pathlib.Path]):
+        if isinstance(url, pathlib.Path):
+            url = core.Url.fromLocalFile(str(url))
+        elif isinstance(url, str):
             url = core.Url(url)
         self.setUrl(url)
 
-    def load_url(self, url):
-        if isinstance(url, str):
+    def load_url(self, url: Union[str, pathlib.Path]):
+        if isinstance(url, pathlib.Path):
+            url = core.Url.fromLocalFile(str(url))
+        elif isinstance(url, str):
             url = core.Url(url)
         self.load(url)
 
