@@ -4,6 +4,7 @@
 """Tests for `prettyqt` package."""
 
 import pickle
+import re
 
 from qtpy import QtCore, QtGui
 
@@ -13,6 +14,15 @@ from prettyqt import core, custom_widgets, gui, widgets
 test_widget = widgets.Widget()
 
 
+def test_booldicttoolbutton():
+    dct = dict(a="test",
+               b="test2")
+    w = custom_widgets.BoolDictToolButton("Title", None, dct)
+    w["a"] = True
+    assert w["a"] is True
+    assert w.as_dict() == dict(a=True, b=False)
+
+
 def test_buttondelegate():
     widget = custom_widgets.ButtonDelegate(parent=None)
     widget.setEditorData(widgets.Widget(), None)
@@ -46,6 +56,15 @@ def test_colorchooserbutton():
     assert btn.is_valid()
 
 
+def test_regexeditor():
+    widget = custom_widgets.RegexEditorWidget()
+    widget.regex = "[0-9]"
+    assert widget.regex == "[0-9]"
+    widget.string = "test123"
+    assert widget.string == "test123"
+    widget.compile_flags = re.IGNORECASE
+
+
 def test_dataset():
 
     class Test(fo.DataSet):
